logTimedEventIdWithParameters static method
Records a timed event named eventId with parameters.
Logs eventId as a timed event with the second key timedId.
Use maximum of 10 parameters to specify the characters of the
event. Returns the event recording status of the logged event.
Implementation
static Future<EventRecordStatus> logTimedEventIdWithParameters(
String eventId, Map<String, String> parameters, String timedId) async {
if (flurryAgent != null) {
int eventRecordStatus = await flurryAgent!
.logTimedEventIdWithParameters(eventId, parameters, timedId);
return EventRecordStatus.values[eventRecordStatus];
}
return EventRecordStatus.eventRecorded;
}