logTimedEventWithParameters static method
Records a timed event named eventId with parameters.
Logs eventId as a non timed event or a timed event based on boolean
timed. Use maximum of 10 parameters to specify the characters of the
event. Returns the event recording status of the logged event.
Implementation
static Future<EventRecordStatus> logTimedEventWithParameters(
String eventId, Map<String, String> parameters, bool timed) async {
if (flurryAgent != null) {
int eventRecordStatus = await flurryAgent!
.logTimedEventWithParameters(eventId, parameters, timed);
return EventRecordStatus.values[eventRecordStatus];
}
return EventRecordStatus.eventRecorded;
}