putBooleanParam method
Sets a Boolean value for a flurry param key.
Returns the Param object after setting boolean value for the Flurry
Defined BooleanParam key.
Implementation
Param putBooleanParam(BooleanParam key, bool value) {
builderAgent?.putBooleanParam(key, value);
return this;
}