putDoubleParam method
Sets a Double value for a flurry param key.
Returns the Param object after setting double value for the Flurry
Defined DoubleParam key
Implementation
Param putDoubleParam(DoubleParam key, double value) {
builderAgent?.putDoubleParam(key, value);
return this;
}